@@ -18,7 +18,6 @@ module Cucumber
       end
 
       def add_feature(feature)
-        feature.features = self
         @features << feature
       end
 
@@ -30,6 +29,10 @@ module Cucumber
         end
         @duration = Time.now - start
       end
+
+      def step_count
+        @features.inject(0) { |total, feature| total += feature.step_count }
+      end
     end
   end
 end
