@@ -1,5 +1,6 @@
 require 'cucumber/cli/profile_loader'
 require 'cucumber/formatter/ansicolor'
+require 'cucumber/rb_support/rb_language'
 
 module Cucumber
   module Cli
@@ -46,7 +47,8 @@ module Cucumber
       OPTIONS_WITH_ARGS = ['-r', '--require', '--i18n', '-f', '--format', '-o', '--out',
                                   '-t', '--tags', '-n', '--name', '-e', '--exclude',
                                   PROFILE_SHORT_FLAG, PROFILE_LONG_FLAG,
-                                  '-a', '--autoformat', '-l', '--lines', '--port']
+                                  '-a', '--autoformat', '-l', '--lines', '--port',
+                                  '-I', '--snippet-type']
 
       def self.parse(args, out_stream, error_stream, options = {})
         new(out_stream, error_stream, options).parse!(args)
@@ -57,11 +59,12 @@ module Cucumber
         @error_stream = error_stream
 
         @default_profile = options[:default_profile]
-        @skip_profile_information = options[:skip_profile_information]
         @profiles = []
         @overridden_paths = []
         @options = default_options
-        
+        @profile_loader = options[:profile_loader]
+        @options[:skip_profile_information] = options[:skip_profile_information]
+
         @quiet = @disable_profile_loading = nil
       end
 
@@ -182,7 +185,7 @@ module Cucumber
             "Beware that if you want to use several negative tags to exclude several tags",
             "you have to use logical AND: --tags ~@fixme --tags ~@buggy.",
             "\n",
-            "Positive tags can be given a threshold to limit the number of occurrences.", 
+            "Positive tags can be given a threshold to limit the number of occurrences.",
             "Example: --tags @qa:3 will fail if there are more than 3 occurrences of the @qa tag.",
             "This can be practical if you are practicing Kanban or CONWIP.") do |v|
             @options[:tag_expressions] << v
@@ -238,6 +241,12 @@ module Cucumber
           opts.on("-i", "--no-snippets", "Don't print snippets for pending steps.") do
             @options[:snippets] = false
           end
+          opts.on("-I", "--snippet-type TYPE",
+                  "Use different snippet type (Default: regexp). Available types:",
+                  *Cucumber::RbSupport::RbLanguage.cli_snippet_type_options) do |v|
+            @options[:snippet_type] = v.to_sym
+          end
+
           opts.on("-q", "--quiet", "Alias for --no-snippets --no-source.") do
             @quiet = true
           end
@@ -293,7 +302,6 @@ module Cucumber
         @options[:paths] = @args.dup #whatver is left over
 
         merge_profiles
-        print_profile_information
 
         self
       end
@@ -343,11 +351,20 @@ module Cucumber
         @profiles << @default_profile if default_profile_should_be_used?
 
         @profiles.each do |profile|
-          profile_args = profile_loader.args_from(profile)
-          reverse_merge(
-            Options.parse(profile_args, @out_stream, @error_stream, :skip_profile_information  => true)
-          )
+          merge_with_profile(profile)
         end
+
+        @options[:profiles] = @profiles
+      end
+
+      def merge_with_profile(profile)
+        profile_args = profile_loader.args_from(profile)
+        profile_options = Options.parse(
+          profile_args, @out_stream, @error_stream,
+          :skip_profile_information => true,
+          :profile_loader => profile_loader
+        )
+        reverse_merge(profile_options)
       end
 
       def default_profile_should_be_used?
@@ -375,6 +392,7 @@ module Cucumber
         @options[:source] &= other_options[:source]
         @options[:snippets] &= other_options[:snippets]
         @options[:strict] |= other_options[:strict]
+        @options[:dry_run] |= other_options[:dry_run]
 
         @profiles += other_options.profiles
         @expanded_args += other_options.expanded_args
@@ -401,15 +419,6 @@ module Cucumber
         Kernel.exit(0)
       end
 
-      def print_profile_information
-        return if @skip_profile_information || @profiles.empty?
-        profiles_sentence = ''
-        profiles_sentence = @profiles.size == 1 ? @profiles.first :
-          "#{@profiles[0...-1].join(', ')} and #{@profiles.last}"
-
-        @out_stream.puts "Using the #{profiles_sentence} profile#{'s' if @profiles.size> 1}..."
-      end
-
       def default_options
         {
           :strict       => false,
