@@ -28,6 +28,10 @@ module Cucumber
       def embed(src, mime_type, label)
         case(mime_type)
         when /^image\/(png|gif|jpg|jpeg)/
+          unless File.file?(src) or src =~ /^data:image\/(png|gif|jpg|jpeg);base64,/
+            type = mime_type =~ /;base[0-9]+$/ ? mime_type : mime_type + ";base64"
+            src = "data:" + type + "," + src
+          end
           embed_image(src, label)
         end
       end
@@ -598,8 +602,12 @@ module Cucumber
 
         def lines_around(file, line)
           if File.file?(file)
+            begin
             lines = File.open(file).read.split("\n")
-            min = [0, line-3].max
+          rescue ArgumentError
+            return "# Couldn't get snippet for #{file}"
+          end
+          min = [0, line-3].max
             max = [line+1, lines.length-1].min
             selected_lines = []
             selected_lines.join("\n")
