@@ -5,7 +5,7 @@ module Cucumber
     class PyLanguage
       include LanguageSupport::LanguageMethods
 
-      def initialize(step_mother)
+      def initialize(runtime)
         @step_def_files = []
         #
         # @python_path = ENV['PYTHONPATH'] ? ENV['PYTHONPATH'].split(':') : []
@@ -24,7 +24,7 @@ module Cucumber
       def alias_adverbs(adverbs)
       end
 
-      def snippet_text(code_keyword, step_name, multiline_arg_class)
+      def snippet_text(code_keyword, step_name, multiline_arg_class, snippet_type)
         "python snippet: #{code_keyword}, #{step_name}"
       end
 
@@ -77,4 +77,4 @@ class String #:nodoc:
       tail == str
     end
   end
-end
\ No newline at end of file
+end
