@@ -9,20 +9,20 @@ module Cli
     end
 
     def given_cucumber_yml_defined_as(hash_or_string)
-      File.stub!(:exist?).and_return(true)
+      File.stub(:exist?).and_return(true)
       cucumber_yml = hash_or_string.is_a?(Hash) ? hash_or_string.to_yaml : hash_or_string
-      IO.stub!(:read).with('cucumber.yml').and_return(cucumber_yml)
+      IO.stub(:read).with('cucumber.yml').and_return(cucumber_yml)
     end
 
     def given_the_following_files(*files)
-      File.stub!(:directory?).and_return(true)
-      File.stub!(:file?).and_return(true)
-      Dir.stub!(:[]).and_return(files)
+      File.stub(:directory?).and_return(true)
+      File.stub(:file?).and_return(true)
+      Dir.stub(:[]).and_return(files)
     end
 
     before(:each) do
-      File.stub!(:exist?).and_return(false) # Meaning, no cucumber.yml exists
-      Kernel.stub!(:exit).and_return(nil)
+      File.stub(:exist?).and_return(false) # Meaning, no cucumber.yml exists
+      Kernel.stub(:exit).and_return(nil)
     end
 
     def config
@@ -127,6 +127,7 @@ module Cli
     end
 
     context '--profile' do
+      include RSpec::WorkInProgress
 
       it "expands args from profiles in the cucumber.yml file" do
         given_cucumber_yml_defined_as({'bongo' => '--require from/yml'})
@@ -151,7 +152,7 @@ module Cli
       end
 
       it "parses ERB syntax in the cucumber.yml file" do
-        given_cucumber_yml_defined_as({'default' => '<%="--require some_file"%>'})
+        given_cucumber_yml_defined_as("---\ndefault: \"<%=\"--require some_file\"%>\"\n")
 
         config.parse!([])
         config.options[:require].should include('some_file')
@@ -309,6 +310,11 @@ END_OF_MESSAGE
       end.should raise_error("All but one formatter must use --out, only one can print to each stream (or STDOUT)")
     end
 
+    it "should accept same --format options with implicit STDOUT, and keep only one" do
+      config.parse!(%w{--format pretty --format pretty})
+      config.formats.should == [["pretty", out]]
+    end
+
     it "should not accept multiple --out streams pointing to the same place" do
       lambda do
         config.parse!(%w{--format pretty --out file1 --format progress --out file1})
@@ -320,6 +326,16 @@ END_OF_MESSAGE
       config.formats.should == [["progress", "file1"], ["profile" ,"file2"]]
     end
 
+    it "should accept same --format options with same --out streams and keep only one" do
+      config.parse!(%w{--format html --out file --format pretty --format html --out file})
+      config.formats.should == [["pretty", out], ["html", "file"]]
+    end
+
+    it "should accept same --format options with different --out streams" do
+      config.parse!(%w{--format html --out file1 --format html --out file2})
+      config.formats.should == [["html", "file1"], ["html", "file2"]]
+    end
+
     it "should accept --color option" do
       Cucumber::Term::ANSIColor.should_receive(:coloring=).with(true)
       config.parse!(['--color'])
@@ -371,9 +387,9 @@ END_OF_MESSAGE
     end
 
     it "should search for all features in the specified directory" do
-      File.stub!(:directory?).and_return(true)
-      Dir.should_receive(:[]).with("feature_directory/**/*.feature").
-        any_number_of_times.and_return(["cucumber.feature"])
+      File.stub(:directory?).and_return(true)
+      Dir.stub(:[]).with("feature_directory/**/*.feature").
+        and_return(["cucumber.feature"])
 
       config.parse!(%w{feature_directory/})
 
@@ -381,9 +397,9 @@ END_OF_MESSAGE
     end
 
     it "defaults to the features directory when no feature file are provided" do
-      File.stub!(:directory?).and_return(true)
-      Dir.should_receive(:[]).with("features/**/*.feature").
-        any_number_of_times.and_return(["cucumber.feature"])
+      File.stub(:directory?).and_return(true)
+      Dir.stub(:[]).with("features/**/*.feature").
+        and_return(["cucumber.feature"])
 
       config.parse!(%w{})
 
@@ -402,36 +418,55 @@ END_OF_MESSAGE
       ENV["RAILS_ENV"].should == "selenium"
       config.feature_files.should_not include('RAILS_ENV=selenium')
     end
-    
+
     describe "#tag_expression" do
       include RSpec::WorkInProgress
 
       it "returns an empty expression when no tags are specified" do
-        pending_under :java, 'the java class Gherkin::TagExpression has no isEmpty method' do
-          config.parse!([])
-          config.tag_expression.should be_empty
-        end
+        config.parse!([])
+        config.tag_expression.should be_empty
       end
 
       it "returns an expression when tags are specified" do
-        pending_under :java, 'the java class Gherkin::TagExpression has no isEmpty method' do
-          config.parse!(['--tags','@foo'])
-          config.tag_expression.should_not be_empty
-        end
+        config.parse!(['--tags','@foo'])
+        config.tag_expression.should_not be_empty
       end
     end
-    
+
     describe "#dry_run?" do
       it "returns true when --dry-run was specified on in the arguments" do
         config.parse!(['--dry-run'])
         config.dry_run?.should be_true
       end
-      
+
+      it "returns true when --dry-run was specified in yaml file" do
+        given_cucumber_yml_defined_as({'default' => '--dry-run'})
+        config.parse!([])
+        config.dry_run?.should be_true
+      end
+
       it "returns false by default" do
         config.parse!([])
         config.dry_run?.should be_false
       end
     end
+
+    describe "#snippet_type" do
+      it "returns the snippet type when it was set" do
+        config.parse!(["--snippet-type", "classic"])
+        config.snippet_type.should eql :classic
+      end
+
+      it "returns the snippet type when it was set with shorthand option" do
+        config.parse!(["-I", "classic"])
+        config.snippet_type.should eql :classic
+      end
+
+      it "returns the default snippet type if it was not set" do
+        config.parse!([])
+        config.snippet_type.should eql :regexp
+      end
+    end
   end
 end
 end
